(function ($, Drupal, drupalSettings) {
  "use strict";
  Drupal.behaviors.CdTimerInit = {
    attach: function attach(context, settings) {
      $(context).find('.ino-countdown[data-cdtimer-id]').once('cdTimerInit').each(function () {
        var id = $(this).data('cdtimer-id');
        if (settings.inoPtCdTimer.hasOwnProperty(id)) {
          var $cdtimer = $(this).children('div.cdtimer');
          //Formatter
          var minutesFormat = '%-N %!N:minute,minutes; %-S %!S:second,seconds;';
          var hoursFormat = '%-I %!I:hour,hours; %-M %!M:minute,minutes; %-S %!S:second,seconds;';
          var daysFormat = '%-D %!D:day,days; %-H %!H:hour,hours; %-M %!M:minute,minutes; %-S %!S:second,seconds;';
          var weeksFormat = '%-w %!w:week,weeks; %-d %!d:day,days; %-H %!H:hour,hours; %-M %!M:minute,minutes; %-S %!S:second,seconds;';
          var monthsFormat = '%-m %!m:month,months; %-n %!n:day,days; %-H %!H:hour,hours; %-M %!M:minute,minutes; %-S %!S:second,seconds;';
          var yearsFormat = '%-Y %!Y:year,years; %-m %!m:month,months; %-n %!n:day,days; %-H %!H:hour,hours; %-M %!M:minute,minutes; %-S %!S:second,seconds;';
          //Units
          var $years = $(this).children('div.cdtimer').find('div.yearsunit');
          var $months = $(this).children('div.cdtimer').find('div.monthsunit');
          var $weeks = $(this).children('div.cdtimer').find('div.weeksunit');
          var $days = $(this).children('div.cdtimer').find('div.daysunit');
          var $hours = $(this).children('div.cdtimer').find('div.hoursunit');
          var $minutes = $(this).children('div.cdtimer').find('div.minutesunit');
          var $seconds = $(this).children('div.cdtimer').find('div.secondsunit');

          var cdDate = settings.inoPtCdTimer[id].date;
          var timezone = settings.inoPtCdTimer[id].timezone;
          // Moment object (date) with a timezone.
          var mCdDate = moment.tz(cdDate, timezone);

          $(this).countdown(mCdDate.toDate())
          .on('update.countdown', function(event) {
            var daysToMonth = event.offset.weeksToMonth*7+event.offset.daysToWeek;

            //Years display
            if (settings.inoPtCdTimer[id].formatter === yearsFormat) {
              $weeks.parent().parent().hide();
              var numberOfYears = 0;
              if (event.offset.months > 12) {
                numberOfYears = Math.trunc(event.offset.months/12);
                $years.html(numberOfYears);
              }
              else {$years.parent().parent().hide();}
              if (event.offset.months > 0) {$months.html(event.offset.months - numberOfYears*12);}
              else {$months.parent().parent().hide();}
              if (event.offset.weeksToMonth > 0) {$weeks.html(event.offset.weeksToMonth);}
              else {$weeks.parent().parent().hide();}
              if (daysToMonth > 0) {$days.html(daysToMonth);}
              else {$days.parent().parent().hide();}
              if (event.offset.hours > 0) {$hours.html(event.offset.hours);}
              else {$hours.parent().parent().hide();}
              if (event.offset.minutes > 0) {$minutes.html(event.offset.minutes);}
              else {$minutes.parent().parent().hide();}
              $seconds.html(event.offset.seconds);
            }

            //Months display
            if (settings.inoPtCdTimer[id].formatter === monthsFormat) {
              $years.parent().parent().hide();
              $weeks.parent().parent().hide();

              if (event.offset.months > 0) {$months.html(event.offset.months);}
              else {$months.parent().parent().hide();}
              if (daysToMonth > 0) {$days.html(daysToMonth);}
              else {$days.parent().parent().hide();}
              if (event.offset.hours > 0) {$hours.html(event.offset.hours);}
              else {$hours.parent().parent().hide();}
              if (event.offset.minutes > 0) {$minutes.html(event.offset.minutes);}
              else {$minutes.parent().parent().hide();}
              $seconds.html(event.offset.seconds);
            }

            //Weeks display
            if (settings.inoPtCdTimer[id].formatter === weeksFormat) {
              $years.parent().parent().hide();
              $months.parent().parent().hide();
              if (event.offset.weeks > 0) {$weeks.html(event.offset.weeks);}
              else {$weeks.parent().parent().hide();}
              if (event.offset.daysToWeek > 0) {$days.html(event.offset.daysToWeek);}
              else {$days.parent().parent().hide();}
              if (event.offset.hours > 0) {$hours.html(event.offset.hours);}
              else {$hours.parent().parent().hide();}
              if (event.offset.minutes > 0) {$minutes.html(event.offset.minutes);}
              else {$minutes.parent().parent().hide();}
              $seconds.html(event.offset.seconds);
            }

             //Days display
            if (settings.inoPtCdTimer[id].formatter === daysFormat) {
              $years.parent().parent().hide();
              $months.parent().parent().hide();
              $weeks.parent().parent().hide();
              if (event.offset.totalDays > 0) {$days.html(event.offset.totalDays);}
              else {$days.parent().parent().hide();}
              if (event.offset.hours > 0) {$hours.html(event.offset.hours);}
              else {$hours.parent().parent().hide();}
              if (event.offset.minutes > 0) {$minutes.html(event.offset.minutes);}
              else {$minutes.parent().parent().hide();}
              $seconds.html(event.offset.seconds);
            }

            //Hours display
            else if (settings.inoPtCdTimer[id].formatter === hoursFormat) {
              $years.parent().parent().hide();
              $months.parent().parent().hide();
              $weeks.parent().parent().hide();
              $days.parent().parent().hide();
              if (event.offset.totalHours > 0) {$hours.html(event.offset.totalHours);}
              else {$hours.parent().parent().hide();}
              if (event.offset.minutes > 0) {$minutes.html(event.offset.minutes);}
              else {$minutes.parent().parent().hide();}
              $seconds.html(event.offset.seconds);
            }

            //Minutes display
            else if (settings.inoPtCdTimer[id].formatter === minutesFormat) {
              $years.parent().parent().hide();
              $months.parent().parent().hide();
              $weeks.parent().parent().hide();
              $days.parent().parent().hide();
              $hours.parent().parent().hide();
              if (event.offset.totalMinutes > 0) {$minutes.html(event.offset.totalMinutes);}
              else {$minutes.parent().parent().hide();}
              $seconds.html(event.offset.seconds);
            }
          })
          .on('finish.countdown', function(event) {
            $cdtimer.hide();
            $(this).children('div.end-text').html(settings.inoPtCdTimer[id].endText).show();
          });
        }
      });
    }
  };
})(jQuery, Drupal, drupalSettings);
